@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-import os, sys, ast, json, glob, platform, subprocess, random, requests, socket
+import os, sys, ast, json, glob, platform, subprocess, random, requests, socket, time
 
 # inc imports.
 import syst3m, cl1
